@@ -503,7 +503,7 @@ rbind.structable <- function(..., deparse.level = 1) {
 
 as.table.structable <- function(x, ...) {
   ret <- stats:::as.table.ftable(x)
-  structure(aperm(ret, match(names(dimnames(ret)), names(attr(x, "dnames")))),
+  structure(aperm(ret, match(names(attr(x, "dnames")), names(dimnames(ret)))),
             class = "table")
 }
 
